@@ -90,9 +90,9 @@ setMethod(f = "getLevels",
         return(object@levels)
       } else {
         if (!(j==1 | j==2)) {
-          error("Index needs to be either 1 or 2.")
+          stop("Index needs to be either 1 or 2.")
         } else {
-          return(object@levels[[1]])
+          return(object@levels[[j]])
         }
       }
     }
