@@ -2,4 +2,4 @@ library(testthat)
 library(quantspec)
 
 #' @importFrom testthat test_package
-test_package("quantspec")
\ No newline at end of file
+test_check("quantspec")
\ No newline at end of file
